Aloe-Django
-------------

Utilities for using Aloe with Django:

- A `harvest` command to run Gherkin tests
- A collection of steps to aid in testing Django applications

Aloe and Aloe-Django are based on [Lettuce](http://lettuce.it/).
